Python nomographs (nomograms).
==============================

PyNomo is a Python software or library to build pdf nomographs. It is mostly written by L.R. and is not in active development.

For documentation / tutorials, visit https://github.com/lefakkomies/pynomo-doc , https://deadreckonings.files.wordpress.com/2009/07/creatingnomogramswithpynomo.pdf or older pynomo.org. 

Includes **nomogen** - a program to auto-generate nomogram approximations with 3 curved lines.

